"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const inquirer_1 = tslib_1.__importDefault(require("inquirer"));
const path_1 = require("path");
const utils_1 = require("../utils");
const WatchHooks_1 = require("../watch/WatchHooks");
exports.KEYS = {
    down: '\u001b[B',
    enter: '\n',
};
exports.shouldSavePrompt = (codePath) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    const { choice } = yield inquirer_1.default.prompt([
        {
            choices: [
                '💾  Save and exit',
                '🖥️  Open REPL to run code',
                '🗑️  Discard and exit',
            ],
            message: `Edit your code at: ${path_1.relative(process.cwd(), codePath)}`,
            name: 'choice',
            type: 'list',
        },
    ]);
    if (choice.includes('REPL')) {
        yield utils_1.repl();
        return exports.shouldSavePrompt(codePath);
    }
    const shouldSave = choice.includes('Save');
    return shouldSave;
});
exports.createPrompt = (codePath) => {
    return new Promise((resolve) => {
        let resolved = false;
        const done = (shouldSave) => {
            if (resolved)
                return;
            resolved = true;
            resolve(shouldSave);
        };
        exports.shouldSavePrompt(codePath).then(done);
        WatchHooks_1.WatchHooks.onStop(() => {
            resolved = true;
            process.stdin.push(exports.KEYS.enter);
            process.stdin.pause();
            resolve(null);
        });
    });
};
//# sourceMappingURL=createPrompt.js.map