"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const debug_1 = tslib_1.__importDefault(require("debug"));
const events_1 = require("events");
const net_1 = require("net");
const split_1 = tslib_1.__importDefault(require("split"));
const debug = debug_1.default('qawolf:WatchClient');
class WatchClient extends events_1.EventEmitter {
    constructor(port) {
        super();
        debug('connect to port %o', port);
        this._socket = net_1.connect({ port });
        this._socket.setEncoding('utf8');
        this._listen();
    }
    _listen() {
        this._socket.on('close', () => {
            this._socket = null;
        });
        this._socket.pipe(split_1.default()).on('data', (data) => {
            debug('received %o', data);
            try {
                const message = JSON.parse(data);
                if (message.name === 'stoptest')
                    this.emit('stoptest');
            }
            catch (e) {
            }
        });
    }
    _send(value) {
        if (!this._socket)
            return;
        debug('send %s', value.name);
        this._socket.write(JSON.stringify(value) + '\n');
    }
    close() {
        if (!this._socket)
            return;
        debug('close');
        this._socket.end();
        this._socket = null;
        this.removeAllListeners();
    }
    sendCodeUpdate(code) {
        this._send({ name: 'codeupdate', code });
    }
    sendStopWatch() {
        this._send({ name: 'stopwatch' });
    }
    sendTestStopped() {
        this._send({ name: 'teststopped' });
    }
}
exports.WatchClient = WatchClient;
//# sourceMappingURL=WatchClient.js.map