"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const debug_1 = tslib_1.__importDefault(require("debug"));
const WatchClient_1 = require("./WatchClient");
const debug = debug_1.default('qawolf:WatchHooks');
class WatchHooks {
    static _handleStopTest() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            if (this._stopped)
                return;
            debug('stop test');
            this._stopped = true;
            const callbacks = this._onStop;
            yield Promise.all(callbacks.map((fn) => fn()));
            debug('onStop hooks done');
            this._client.sendTestStopped();
            this._client.close();
            this._client = null;
        });
    }
    static _connect() {
        const port = process.env.QAW_WATCH_SERVER_PORT;
        if (this._client || !port)
            return;
        this._client = new WatchClient_1.WatchClient(Number(port));
        this._client.once('stoptest', () => this._handleStopTest());
    }
    static close() {
        if (this._stopped || !this._client)
            return;
        this._client.close();
        this._client = null;
    }
    static codeUpdate(code) {
        if (!this._client)
            return;
        this._client.sendCodeUpdate(code);
    }
    static enabled() {
        return !!this._client;
    }
    static onStop(callback) {
        this._onStop.push(callback);
    }
    static stopWatch() {
        if (!this._client)
            return;
        this._client.sendStopWatch();
    }
}
exports.WatchHooks = WatchHooks;
WatchHooks._onStop = [];
WatchHooks._connect();
//# sourceMappingURL=WatchHooks.js.map