"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const chokidar_1 = require("chokidar");
const debug_1 = tslib_1.__importDefault(require("debug"));
const fs_extra_1 = require("fs-extra");
const WatchServer_1 = require("./WatchServer");
const debug = debug_1.default('qawolf:WatchPlugin');
class WatchPlugin {
    constructor() {
        this._lastCodeUpdate = Date.now();
        this._server = new WatchServer_1.WatchServer();
        this._server.on('codeupdate', (code) => {
            this._lastCodeUpdate = Date.now();
            this._code = code;
        });
        this._server.on('stopwatch', () => this._stop());
    }
    _beforeTest(testPath) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            debug('before test %s', testPath);
            this._server.stopTest();
            yield this._server.setEnv(process.env);
            yield this._watch(testPath);
        });
    }
    _onWatchChange(testPath) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const newCode = yield fs_extra_1.readFile(testPath, 'utf8');
            if (newCode === this._code || Date.now() - this._lastCodeUpdate < 100) {
                debug('watch change: code did not change');
                return;
            }
            debug('watch change: code changed');
            this._code = newCode;
            yield this._server.stopTest();
            this._triggerTest(testPath);
        });
    }
    _stop() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            debug('stop');
            yield Promise.all([this._watcher.close(), this._server.stopTest()]);
            process.exit();
        });
    }
    _triggerTest(testPath) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            debug('trigger test');
            this._code = yield fs_extra_1.readFile(testPath, 'utf8');
            yield fs_extra_1.writeFile(testPath, this._code, 'utf8');
        });
    }
    _watch(testPath) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            if (this._watchPath === testPath)
                return;
            if (this._watcher)
                this._watcher.close();
            debug('watch %s', testPath);
            this._watchPath = testPath;
            this._watcher = chokidar_1.watch(testPath, { atomic: 0 });
            this._code = yield fs_extra_1.readFile(testPath, 'utf8');
            this._watcher.on('change', () => this._onWatchChange(testPath));
        });
    }
    apply(hooks) {
        hooks.shouldRunTestSuite((suite) => tslib_1.__awaiter(this, void 0, void 0, function* () {
            yield this._beforeTest(suite.testPath);
            return true;
        }));
    }
}
exports.WatchPlugin = WatchPlugin;
//# sourceMappingURL=WatchPlugin.js.map