"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const debug_1 = tslib_1.__importDefault(require("debug"));
const events_1 = require("events");
const net_1 = require("net");
const split_1 = tslib_1.__importDefault(require("split"));
const debug = debug_1.default('qawolf:WatchServer');
class WatchServer extends events_1.EventEmitter {
    constructor() {
        super();
        this._server = net_1.createServer((socket) => {
            this._setSocket(socket);
        });
        this._ready = new Promise((resolve) => this._server.listen(0, resolve));
    }
    _setSocket(socket) {
        debug('set socket %o', socket.address());
        this._socket = socket;
        this._socket.pipe(split_1.default()).on('data', (data) => {
            debug('received %o', data);
            try {
                const message = JSON.parse(data);
                if (message.name === 'codeupdate') {
                    this.emit('codeupdate', message.code);
                }
                else if (message.name === 'stopwatch') {
                    this.emit('stopwatch');
                }
                else if (message.name === 'teststopped') {
                    this.emit('teststopped');
                }
            }
            catch (e) {
            }
        });
    }
    close() {
        debug('close');
        this._server.close();
    }
    port() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            yield this._ready;
            const address = this._server.address();
            return address.port;
        });
    }
    setEnv(env) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const port = yield this.port();
            debug('setEnv QAW_WATCH_SERVER_PORT %s', port);
            env.QAW_WATCH_SERVER_PORT = `${port}`;
        });
    }
    stopTest() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            if (!this._socket || this._socket.destroyed)
                return;
            debug('stop test');
            try {
                const hasStopped = new Promise((resolve) => {
                    this.once('teststopped', () => resolve());
                });
                this._socket.write(JSON.stringify({ name: 'stoptest' }) + '\n');
                yield hasStopped;
            }
            catch (e) {
                debug('error sending stoptest %o', e);
            }
        });
    }
}
exports.WatchServer = WatchServer;
//# sourceMappingURL=WatchServer.js.map